@@ -36,9 +36,9 @@ function Layer(guiAction) {
 
     this.documentInterface = undefined;
 
-    if (!isNull(guiAction) && !isNull(guiAction.getDocumentInterface())) {
-        this.setDocumentInterface(guiAction.getDocumentInterface());
-    }
+//    if (!isNull(guiAction) && !isNull(guiAction.getDocumentInterface())) {
+//        this.setDocumentInterface(guiAction.getDocumentInterface());
+//    }
 }
 
 Layer.prototype = new EAction();
@@ -136,7 +136,33 @@ Layer.init = function() {
     Layer.getToolMatrixPanel();
 };
 
-Layer.showHide = function(show, obj, layerId, showProgress) {
+Layer.getShowFrozen = function() {
+    if (hasPlugin("PROTOOLS")) {
+        return RSettings.getBoolValue("LayerListPro/ShowFrozen", false);
+    }
+    else {
+        return false;
+    }
+};
+
+Layer.getFreezeLayer = function() {
+    if (hasPlugin("PROTOOLS")) {
+        return RSettings.getBoolValue("LayerListPro/FreezeLayer", true);
+    }
+    else {
+        return true;
+    }
+};
+
+/**
+ * Show / hide all layers.
+ *
+ * \param show True to show, false to hide all
+ * \param di RDocumentInterface
+ * \param layerId ID of layer to exempt from the action
+ * \param showProgress True to show progress information to progress listeners
+ */
+Layer.showHide = function(show, di, layerId, showProgress) {
     if (showProgress===true) {
         if (show) {
             EAction.setProgressText(qsTr("Showing all layers"));
@@ -146,16 +172,17 @@ Layer.showHide = function(show, obj, layerId, showProgress) {
         }
     }
 
-    var showFrozen = RSettings.getBoolValue("LayerListPro/ShowFrozen", false);
+    var showFrozen = Layer.getShowFrozen();
+    var freezeLayer = Layer.getFreezeLayer();
 
     var operation = new RModifyObjectsOperation();
-    var layers = obj.getDocument().queryAllLayers();
+    var layers = di.getDocument().queryAllLayers();
     for (var l = 0; l < layers.length; ++l) {
         if (showProgress===true) {
             EAction.setProgress(100/layers.length*l);
         }
 
-        var layer = obj.getDocument().queryLayer(layers[l]);
+        var layer = di.getDocument().queryLayer(layers[l]);
         if (layers[l] !== layerId) {
             if (showFrozen) {
                 layer.setOff(!show);
@@ -175,7 +202,6 @@ Layer.showHide = function(show, obj, layerId, showProgress) {
         }
         operation.addObject(layer);
     }
-    var di = obj.getDocumentInterface();
     di.applyOperation(operation);
     di.clearPreview();
     di.repaintViews();
@@ -185,7 +211,7 @@ Layer.showHide = function(show, obj, layerId, showProgress) {
     }
 };
 
-Layer.thawFreeze = function(freeze, obj, layerId, showProgress) {
+Layer.thawFreeze = function(freeze, di, layerId, showProgress) {
     if (showProgress===true) {
         if (freeze) {
             EAction.setProgressText(qsTr("Thawing all layers"));
@@ -196,13 +222,13 @@ Layer.thawFreeze = function(freeze, obj, layerId, showProgress) {
     }
 
     var operation = new RModifyObjectsOperation();
-    var layers = obj.getDocument().queryAllLayers();
+    var layers = di.getDocument().queryAllLayers();
     for (var l = 0; l < layers.length; ++l) {
         if (showProgress===true) {
             EAction.setProgress(100/layers.length*l);
         }
 
-        var layer = obj.getDocument().queryLayer(layers[l]);
+        var layer = di.getDocument().queryLayer(layers[l]);
         if (layers[l] !== layerId) {
             layer.setFrozen(!freeze);
         } else {
@@ -210,7 +236,6 @@ Layer.thawFreeze = function(freeze, obj, layerId, showProgress) {
         }
         operation.addObject(layer);
     }
-    var di = obj.getDocumentInterface();
     di.applyOperation(operation);
     di.clearPreview();
     di.repaintViews();
